`timescale 1ns/10ps
`celldefine
module AND2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   and (Y, A, B);

   specify
     // delay parameters
     specparam
       tpllh$B$Y = 0.136152:0.136152:0.136152,
       tphhl$B$Y = 0.184677:0.184677:0.184677,
       tpllh$A$Y = 0.135468:0.135468:0.135468,
       tphhl$A$Y = 0.167177:0.167177:0.167177;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tphhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module AND2X2 (A, B, Y);
input  A ;
input  B ;
output Y ;

   and (Y, A, B);

   specify
     // delay parameters
     specparam
       tpllh$A$Y = 0.16526:0.16526:0.16526,
       tphhl$A$Y = 0.197548:0.197548:0.197548,
       tpllh$B$Y = 0.165586:0.165586:0.165586,
       tphhl$B$Y = 0.21246:0.21246:0.21246;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tphhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module AOI21X1 (A, B, C, Y);
input  A ;
input  B ;
input  C ;
output Y ;

   and (I0_out, A, B);
   or  (I1_out, I0_out, C);
   not (Y, I1_out);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.110736:0.110736:0.110736,
       tphlh$A$Y = 0.119567:0.119567:0.119567,
       tplhl$B$Y = 0.110229:0.110229:0.110229,
       tphlh$B$Y = 0.105819:0.105819:0.105819,
       tplhl$C$Y = 0.11238:0.120576:0.128773,
       tphlh$C$Y = 0.0690998:0.0852486:0.101397;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module AOI22X1 (A, B, C, D, Y);
input  A ;
input  B ;
input  C ;
input  D ;
output Y ;

   and (I0_out, A, B);
   and (I1_out, C, D);
   or  (I2_out, I0_out, I1_out);
   not (Y, I2_out);

   specify
     // delay parameters
     specparam
       tplhl$C$Y = 0.0894587:0.094805:0.100151,
       tphlh$C$Y = 0.0889636:0.107957:0.126951,
       tplhl$D$Y = 0.0885114:0.0937163:0.0989211,
       tphlh$D$Y = 0.0814932:0.0979614:0.11443,
       tplhl$A$Y = 0.120343:0.133942:0.14754,
       tphlh$A$Y = 0.117449:0.131377:0.145305,
       tplhl$B$Y = 0.119781:0.133469:0.147157,
       tphlh$B$Y = 0.106704:0.120762:0.13482;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);
     (D *> Y) = (tphlh$D$Y, tplhl$D$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module BUFX2 (A, Y);
input  A ;
output Y ;

   buf (Y, A);

   specify
     // delay parameters
     specparam
       tpllh$A$Y = 0.190325:0.190325:0.190325,
       tphhl$A$Y = 0.184353:0.184353:0.184353;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module BUFX4 (A, Y);
input  A ;
output Y ;

   buf (Y, A);

   specify
     // delay parameters
     specparam
       tpllh$A$Y = 0.206474:0.206474:0.206474,
       tphhl$A$Y = 0.204188:0.204188:0.204188;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module DFFNEGX1 (CLK, D, Q);
input  CLK ;
input  D ;
output Q ;
reg NOTIFIER ;

   not (I0_CLOCK, CLK);
   udp_dff (DS0000, D, I0_CLOCK, 1'B0, 1'B0, NOTIFIER);
   not (P0002, DS0000);
   buf (Q, DS0000);

   specify
     // delay parameters
     specparam
       tphlh$CLK$Q = 0.265606:0.265606:0.265606,
       tphhl$CLK$Q = 0.235277:0.235277:0.235277,
       tsetup_posedge$D$CLK = 0.28125:0.28125:0.28125,
       tsetup_negedge$D$CLK = 0.375:0.375:0.375,
       thold_posedge$D$CLK = -0.0937499:-0.0937499:-0.0937499,
       thold_negedge$D$CLK = -0.0937499:-0.0937499:-0.0937499,
       tminpwh$CLK = 0.0770513:0.175165:0.273279,
       tminpwl$CLK = 0.141114:0.20336:0.265606;

     // path delays
     if (CLK == 1'b0)
       (CLK *> Q) = (tphlh$CLK$Q, tphhl$CLK$Q);
     $setuphold(negedge CLK, negedge D, tsetup_negedge$D$CLK, thold_negedge$D$CLK, NOTIFIER);
     $setuphold(negedge CLK, posedge D, tsetup_posedge$D$CLK, thold_posedge$D$CLK, NOTIFIER);
     $width(posedge CLK, tminpwh$CLK, 0, NOTIFIER);
     $width(negedge CLK, tminpwl$CLK, 0, NOTIFIER);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module DFFPOSX1 (CLK, D, Q);
input  CLK ;
input  D ;
output Q ;
reg NOTIFIER ;

   udp_dff (DS0000, D, CLK, 1'B0, 1'B0, NOTIFIER);
   not (P0002, DS0000);
   buf (Q, DS0000);

   specify
     // delay parameters
     specparam
       tpllh$CLK$Q = 0.210303:0.210303:0.210303,
       tplhl$CLK$Q = 0.303149:0.303149:0.303149,
       tsetup_posedge$D$CLK = 0.28125:0.28125:0.28125,
       tsetup_negedge$D$CLK = 0.28125:0.28125:0.28125,
       thold_posedge$D$CLK = -0.0937499:-0.0937499:-0.0937499,
       thold_negedge$D$CLK = -0.0937499:-0.0937499:-0.0937499,
       tminpwh$CLK = 0.104545:0.203847:0.303149,
       tminpwl$CLK = 0.0853487:0.179122:0.272895;

     // path delays
     if (CLK == 1'b1)
       (CLK *> Q) = (tpllh$CLK$Q, tplhl$CLK$Q);
     $setuphold(posedge CLK, negedge D, tsetup_negedge$D$CLK, thold_negedge$D$CLK, NOTIFIER);
     $setuphold(posedge CLK, posedge D, tsetup_posedge$D$CLK, thold_posedge$D$CLK, NOTIFIER);
     $width(posedge CLK, tminpwh$CLK, 0, NOTIFIER);
     $width(negedge CLK, tminpwl$CLK, 0, NOTIFIER);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module FAX1 (A, B, C, YC, YS);
input  A ;
input  B ;
input  C ;
output YC ;
output YS ;

   and (I0_out, A, B);
   and (I1_out, B, C);
   or  (I2_out, I0_out, I1_out);
   and (I3_out, C, A);
   or  (YC, I2_out, I3_out);
   xor (I5_out, A, B);
   xor (YS, I5_out, C);

   specify
     // delay parameters
     specparam
       tpllh$A$YS = 0.341965:0.362431:0.382897,
       tplhl$A$YS = 0.376731:0.383533:0.390334,
       tpllh$A$YC = 0.240056:0.242292:0.244527,
       tphhl$A$YC = 0.26904:0.269289:0.269539,
       tpllh$B$YS = 0.351561:0.382649:0.413737,
       tplhl$B$YS = 0.374805:0.398666:0.422527,
       tpllh$B$YC = 0.226574:0.252597:0.278619,
       tphhl$B$YC = 0.277509:0.280266:0.283023,
       tpllh$C$YS = 0.361346:0.37741:0.393474,
       tplhl$C$YS = 0.370222:0.375669:0.381117,
       tpllh$C$YC = 0.221098:0.233744:0.24639,
       tphhl$C$YC = 0.258964:0.260837:0.26271;

     // path delays
     (A *> YC) = (tpllh$A$YC, tphhl$A$YC);
     (A *> YS) = (tpllh$A$YS, tplhl$A$YS);
     (B *> YC) = (tpllh$B$YC, tphhl$B$YC);
     (B *> YS) = (tpllh$B$YS, tplhl$B$YS);
     (C *> YC) = (tpllh$C$YC, tphhl$C$YC);
     (C *> YS) = (tpllh$C$YS, tplhl$C$YS);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module HAX1 (A, B, YC);
input  A ;
input  B ;
output YC ;

   and (YC, A, B);

   specify
     // delay parameters
     specparam
       tpllh$A$YC = 0.175829:0.175829:0.175829,
       tphhl$A$YC = 0.233916:0.233916:0.233916,
       tpllh$B$YC = 0.174883:0.174883:0.174883,
       tphhl$B$YC = 0.214154:0.214154:0.214154;

     // path delays
     (A *> YC) = (tpllh$A$YC, tphhl$A$YC);
     (B *> YC) = (tpllh$B$YC, tphhl$B$YC);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module INVX1 (A, Y);
input  A ;
output Y ;

   not (Y, A);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0908982:0.0908982:0.0908982,
       tphlh$A$Y = 0.0809571:0.0809571:0.0809571;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module INVX2 (A, Y);
input  A ;
output Y ;

   not (Y, A);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0832355:0.0832355:0.0832355,
       tphlh$A$Y = 0.0794573:0.0794573:0.0794573;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module INVX4 (A, Y);
input  A ;
output Y ;

   not (Y, A);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0832355:0.0832355:0.0832355,
       tphlh$A$Y = 0.0794573:0.0794573:0.0794573;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module INVX8 (A, Y);
input  A ;
output Y ;

   not (Y, A);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0832355:0.0832355:0.0832355,
       tphlh$A$Y = 0.0794573:0.0794573:0.0794573;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module MUX2X1 (A, B, S, Y);
input  A ;
input  B ;
input  S ;
output Y ;

   udp_mux2 (I0_out, B, A, S);
   not (Y, I0_out);

   specify
     // delay parameters
     specparam
       tpllh$S$Y = 0.205605:0.205605:0.205605,
       tplhl$S$Y = 0.199127:0.199127:0.199127,
       tplhl$A$Y = 0.105022:0.105022:0.105022,
       tphlh$A$Y = 0.130958:0.130958:0.130958,
       tplhl$B$Y = 0.117626:0.117626:0.117626,
       tphlh$B$Y = 0.118089:0.118089:0.118089;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (S *> Y) = (tpllh$S$Y, tplhl$S$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module NAND2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   and (I0_out, A, B);
   not (Y, I0_out);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0710613:0.0710613:0.0710613,
       tphlh$A$Y = 0.103824:0.103824:0.103824,
       tplhl$B$Y = 0.0718746:0.0718746:0.0718746,
       tphlh$B$Y = 0.0921573:0.0921573:0.0921573;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module NAND3X1 (A, B, C, Y);
input  A ;
input  B ;
input  C ;
output Y ;

   and (I0_out, A, B);
   and (I1_out, I0_out, C);
   not (Y, I1_out);

   specify
     // delay parameters
     specparam
       tplhl$B$Y = 0.0763875:0.0763875:0.0763875,
       tphlh$B$Y = 0.126844:0.126844:0.126844,
       tplhl$A$Y = 0.0781289:0.0781289:0.0781289,
       tphlh$A$Y = 0.145957:0.145957:0.145957,
       tplhl$C$Y = 0.0650131:0.0650131:0.0650131,
       tphlh$C$Y = 0.101279:0.101279:0.101279;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module NOR2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   or  (I0_out, A, B);
   not (Y, I0_out);

   specify
     // delay parameters
     specparam
       tplhl$B$Y = 0.116136:0.116136:0.116136,
       tphlh$B$Y = 0.0860717:0.0860717:0.0860717,
       tplhl$A$Y = 0.150074:0.150074:0.150074,
       tphlh$A$Y = 0.0934715:0.0934715:0.0934715;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module NOR3X1 (A, B, C, Y);
input  A ;
input  B ;
input  C ;
output Y ;

   or  (I0_out, A, B);
   or  (I1_out, I0_out, C);
   not (Y, I1_out);

   specify
     // delay parameters
     specparam
       tplhl$B$Y = 0.202035:0.202035:0.202035,
       tphlh$B$Y = 0.122952:0.122952:0.122952,
       tplhl$C$Y = 0.135743:0.135743:0.135743,
       tphlh$C$Y = 0.0856614:0.0856614:0.0856614,
       tplhl$A$Y = 0.240857:0.240857:0.240857,
       tphlh$A$Y = 0.134381:0.134381:0.134381;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module OAI21X1 (A, B, C, Y);
input  A ;
input  B ;
input  C ;
output Y ;

   or  (I0_out, A, B);
   and (I1_out, I0_out, C);
   not (Y, I1_out);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.110401:0.110401:0.110401,
       tphlh$A$Y = 0.118532:0.118532:0.118532,
       tplhl$B$Y = 0.0889442:0.0889442:0.0889442,
       tphlh$B$Y = 0.106728:0.106728:0.106728,
       tplhl$C$Y = 0.0626089:0.0822925:0.101976,
       tphlh$C$Y = 0.0935288:0.0987512:0.103973;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module OAI22X1 (A, B, C, D, Y);
input  A ;
input  B ;
input  C ;
input  D ;
output Y ;

   or  (I0_out, A, B);
   or  (I1_out, C, D);
   and (I2_out, I0_out, I1_out);
   not (Y, I2_out);

   specify
     // delay parameters
     specparam
       tplhl$D$Y = 0.077825:0.100185:0.122546,
       tphlh$D$Y = 0.0973219:0.102059:0.106797,
       tplhl$C$Y = 0.094452:0.119006:0.143561,
       tphlh$C$Y = 0.107451:0.112429:0.117408,
       tplhl$A$Y = 0.0998376:0.123608:0.147378,
       tphlh$A$Y = 0.12529:0.131748:0.138207,
       tplhl$B$Y = 0.0828228:0.104778:0.126734,
       tphlh$B$Y = 0.114409:0.121859:0.129309;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);
     (D *> Y) = (tphlh$D$Y, tplhl$D$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module OR2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   or  (Y, A, B);

   specify
     // delay parameters
     specparam
       tpllh$B$Y = 0.217882:0.217882:0.217882,
       tphhl$B$Y = 0.178768:0.178768:0.178768,
       tpllh$A$Y = 0.168124:0.168124:0.168124,
       tphhl$A$Y = 0.167235:0.167235:0.167235;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tphhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module OR2X2 (A, B, Y);
input  A ;
input  B ;
output Y ;

   or  (Y, A, B);

   specify
     // delay parameters
     specparam
       tpllh$B$Y = 0.26144:0.26144:0.26144,
       tphhl$B$Y = 0.199666:0.199666:0.199666,
       tpllh$A$Y = 0.21564:0.21564:0.21564,
       tphhl$A$Y = 0.192162:0.192162:0.192162;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tphhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module PADINC (YPAD, DI);
input  YPAD ;
output DI ;

   buf (DI, YPAD);

   specify
     // delay parameters
     specparam
       tpllh$YPAD$DI = 0.108026:0.108026:0.108026,
       tphhl$YPAD$DI = 0.115822:0.115822:0.115822;

     // path delays
     (YPAD *> DI) = (tpllh$YPAD$DI, tphhl$YPAD$DI);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module PADINOUT (DO, OEN, DI, YPAD);
input  DO ;
input  OEN ;
output DI ;
inout  YPAD ;

   bufif1 (YPAD, DO, OEN);
   buf (DI, YPAD);

   specify
     // delay parameters
     specparam
       tpllh$DO$YPAD = 0.693264:0.693264:0.693264,
       tphhl$DO$YPAD = 0.50214:0.50214:0.50214,
       tpzh$OEN$YPAD = 0.86038:0.86038:0.86038,
       tpzl$OEN$YPAD = 0.558941:0.558941:0.558941,
       tplz$OEN$YPAD = 0.486388:0.486388:0.486388,
       tphz$OEN$YPAD = 0.619694:0.619694:0.619694,
       tpllh$YPAD$DI = 0.107478:0.107478:0.107478,
       tphhl$YPAD$DI = 0.115822:0.115822:0.115822;

     // path delays
     (DO *> YPAD) = (tpllh$DO$YPAD, tphhl$DO$YPAD);
     (OEN *> YPAD) = (0, 0, tplz$OEN$YPAD, tpzh$OEN$YPAD, tphz$OEN$YPAD, tpzl$OEN$YPAD);
     (YPAD *> DI) = (tpllh$YPAD$DI, tphhl$YPAD$DI);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module PADOUT (DO, YPAD);
input  DO ;
output YPAD ;

   buf (YPAD, DO);

   specify
     // delay parameters
     specparam
       tpllh$DO$YPAD = 0.693264:0.693264:0.693264,
       tphhl$DO$YPAD = 0.50214:0.50214:0.50214;

     // path delays
     (DO *> YPAD) = (tpllh$DO$YPAD, tphhl$DO$YPAD);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module TBUFX1 (A, EN, Y);
input  A ;
input  EN ;
output Y ;

   not (I0_out, A);
   bufif1 (Y, I0_out, EN);

   specify
     // delay parameters
     specparam
       tpzh$EN$Y = 0.137042:0.137042:0.137042,
       tpzl$EN$Y = 0.0528154:0.0528154:0.0528154,
       tplz$EN$Y = 0.0555:0.0555:0.0555,
       tphz$EN$Y = 0.106389:0.106389:0.106389,
       tplhl$A$Y = 0.0980208:0.0980208:0.0980208,
       tphlh$A$Y = 0.123226:0.123226:0.123226;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (EN *> Y) = (0, 0, tplz$EN$Y, tpzh$EN$Y, tphz$EN$Y, tpzl$EN$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module TBUFX2 (A, EN, Y);
input  A ;
input  EN ;
output Y ;

   not (I0_out, A);
   bufif1 (Y, I0_out, EN);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0989032:0.0989032:0.0989032,
       tphlh$A$Y = 0.121959:0.121959:0.121959,
       tpzh$EN$Y = 0.130082:0.130082:0.130082,
       tpzl$EN$Y = 0.0521681:0.0521681:0.0521681,
       tplz$EN$Y = 0.0555:0.0555:0.0555,
       tphz$EN$Y = 0.104296:0.104296:0.104296;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (EN *> Y) = (0, 0, tplz$EN$Y, tpzh$EN$Y, tphz$EN$Y, tpzl$EN$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module XNOR2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   xor (I0_out, A, B);
   not (Y, I0_out);

   specify
     // delay parameters
     specparam
       tpllh$A$Y = 0.156815:0.156815:0.156815,
       tplhl$A$Y = 0.15237:0.15237:0.15237,
       tpllh$B$Y = 0.183189:0.183189:0.183189,
       tplhl$B$Y = 0.17143:0.17143:0.17143;

     // path delays
     (A *> Y) = (tpllh$A$Y, tplhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tplhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module XOR2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   xor (Y, A, B);

   specify
     // delay parameters
     specparam
       tpllh$B$Y = 0.17819:0.17819:0.17819,
       tplhl$B$Y = 0.176759:0.176759:0.176759,
       tpllh$A$Y = 0.157363:0.157363:0.157363,
       tplhl$A$Y = 0.152464:0.152464:0.152464;

     // path delays
     (A *> Y) = (tpllh$A$Y, tplhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tplhl$B$Y);

   endspecify

endmodule
`endcelldefine

primitive udp_dff (out, in, clk, clr, set, NOTIFIER);
   output out;
   input  in, clk, clr, set, NOTIFIER;
   reg    out;

   table

// in  clk  clr   set  NOT  : Qt : Qt+1
//
   0  r   ?   0   ?   : ?  :  0  ; // clock in 0
   1  r   0   ?   ?   : ?  :  1  ; // clock in 1
   1  *   0   ?   ?   : 1  :  1  ; // reduce pessimism
   0  *   ?   0   ?   : 0  :  0  ; // reduce pessimism
   ?  f   ?   ?   ?   : ?  :  -  ; // no changes on negedge clk
   *  b   ?   ?   ?   : ?  :  -  ; // no changes when in switches
   ?  ?   ?   1   ?   : ?  :  1  ; // set output
   ?  b   0   *   ?   : 1  :  1  ; // cover all transistions on set
   1  x   0   *   ?   : 1  :  1  ; // cover all transistions on set
   ?  ?   1   0   ?   : ?  :  0  ; // reset output
   ?  b   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   0  x   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   ?  ?   ?   ?   *   : ?  :  x  ; // any notifier changed

   endtable
endprimitive // udp_dff

primitive udp_tlat (out, in, enable, clr, set, NOTIFIER);

   output out;
   input  in, enable, clr, set, NOTIFIER;
   reg    out;

   table

// in  enable  clr   set  NOT  : Qt : Qt+1
//
   1  1   0   ?   ?   : ?  :  1  ; //
   0  1   ?   0   ?   : ?  :  0  ; //
   1  *   0   ?   ?   : 1  :  1  ; // reduce pessimism
   0  *   ?   0   ?   : 0  :  0  ; // reduce pessimism
   *  0   ?   ?   ?   : ?  :  -  ; // no changes when in switches
   ?  ?   ?   1   ?   : ?  :  1  ; // set output
   ?  0   0   *   ?   : 1  :  1  ; // cover all transistions on set
   1  ?   0   *   ?   : 1  :  1  ; // cover all transistions on set
   ?  ?   1   0   ?   : ?  :  0  ; // reset output
   ?  0   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   0  ?   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   ?  ?   ?   ?   *   : ?  :  x  ; // any notifier changed

   endtable
endprimitive // udp_tlat

primitive udp_rslat (out, clr, set, NOTIFIER);

   output out;
   input  clr, set, NOTIFIER;
   reg    out;

   table

// clr   set  NOT  : Qt : Qt+1
//
   ?   1   ?   : ?  :  1  ; // set output
   0   *   ?   : 1  :  1  ; // cover all transistions on set
   1   0   ?   : ?  :  0  ; // reset output
   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   ?   ?   *   : ?  :  x  ; // any notifier changed

   endtable
endprimitive // udp_tlat

primitive udp_mux2 (out, in0, in1, sel);
   output out;
   input  in0, in1, sel;

   table

// sel in0 in1 :  out
//
    1  ?  0 :  1 ;
    0  ?  0 :  0 ;
    ?  1  1 :  1 ;
    ?  0  1 :  0 ;
    0  0  x :  0 ;
    1  1  x :  1 ;

   endtable
endprimitive // udp_mux2

