`timescale 1ns/10ps
`celldefine
module AND2X2 (A, B, Y);
input  A ;
input  B ;
output Y ;

   and (Y, A, B);

   specify
     // delay parameters
     specparam
       tpllh$A$Y = 0.103305:0.103305:0.103305,
       tphhl$A$Y = 0.125756:0.125756:0.125756,
       tpllh$B$Y = 0.101792:0.101792:0.101792,
       tphhl$B$Y = 0.136619:0.136619:0.136619;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tphhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module AOI21X1 (A, B, C, Y);
input  A ;
input  B ;
input  C ;
output Y ;

   and (I0_out, A, B);
   or  (I1_out, I0_out, C);
   not (Y, I1_out);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0599555:0.0599555:0.0599555,
       tphlh$A$Y = 0.084095:0.084095:0.084095,
       tplhl$B$Y = 0.0598237:0.0598237:0.0598237,
       tphlh$B$Y = 0.0715304:0.0715304:0.0715304,
       tplhl$C$Y = 0.0531492:0.056212:0.0592747,
       tphlh$C$Y = 0.0467928:0.0592323:0.0716717;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module AOI22X1 (A, B, C, D, Y);
input  A ;
input  B ;
input  C ;
input  D ;
output Y ;

   and (I0_out, A, B);
   and (I1_out, C, D);
   or  (I2_out, I0_out, I1_out);
   not (Y, I2_out);

   specify
     // delay parameters
     specparam
       tplhl$C$Y = 0.0515269:0.0535802:0.0556336,
       tphlh$C$Y = 0.0650908:0.0796922:0.0942937,
       tplhl$D$Y = 0.0523371:0.0539745:0.0556119,
       tphlh$D$Y = 0.0568724:0.0692031:0.0815339,
       tplhl$A$Y = 0.0691163:0.0748505:0.0805847,
       tphlh$A$Y = 0.0874578:0.0995964:0.111735,
       tplhl$B$Y = 0.0688617:0.0745966:0.0803315,
       tphlh$B$Y = 0.0767428:0.0876119:0.098481;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);
     (D *> Y) = (tphlh$D$Y, tplhl$D$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module BUFX2 (A, Y);
input  A ;
output Y ;

   buf (Y, A);

   specify
     // delay parameters
     specparam
       tpllh$A$Y = 0.106893:0.106893:0.106893,
       tphhl$A$Y = 0.115307:0.115307:0.115307;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module BUFX4 (A, Y);
input  A ;
output Y ;

   buf (Y, A);

   specify
     // delay parameters
     specparam
       tpllh$A$Y = 0.12197:0.12197:0.12197,
       tphhl$A$Y = 0.130871:0.130871:0.130871;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module DFFNEGX1 (CLK, D, Q);
input  CLK ;
input  D ;
output Q ;
reg NOTIFIER ;

   not (I0_CLOCK, CLK);
   udp_dff (DS0000, D, I0_CLOCK, 1'B0, 1'B0, NOTIFIER);
   not (P0002, DS0000);
   buf (Q, DS0000);

   specify
     // delay parameters
     specparam
       tphlh$CLK$Q = 0.161859:0.161859:0.161859,
       tphhl$CLK$Q = 0.159062:0.159062:0.159062,
       tsetup_posedge$D$CLK = 0.25625:0.25625:0.25625,
       tsetup_negedge$D$CLK = 0.25625:0.25625:0.25625,
       thold_posedge$D$CLK = -0.0687499:-0.0687499:-0.0687499,
       thold_negedge$D$CLK = -0.0687499:-0.0687499:-0.0687499,
       tminpwh$CLK = 0.0501628:0.120381:0.190599,
       tminpwl$CLK = 0.103203:0.132531:0.161859;

     // path delays
     if (CLK == 1'b0)
       (CLK *> Q) = (tphlh$CLK$Q, tphhl$CLK$Q);
     $setuphold(negedge CLK, negedge D, tsetup_negedge$D$CLK, thold_negedge$D$CLK, NOTIFIER);
     $setuphold(negedge CLK, posedge D, tsetup_posedge$D$CLK, thold_posedge$D$CLK, NOTIFIER);
     $width(posedge CLK, tminpwh$CLK, 0, NOTIFIER);
     $width(negedge CLK, tminpwl$CLK, 0, NOTIFIER);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module DFFPOSX1 (CLK, D, Q);
input  CLK ;
input  D ;
output Q ;
reg NOTIFIER ;

   udp_dff (DS0000, D, CLK, 1'B0, 1'B0, NOTIFIER);
   not (P0002, DS0000);
   buf (Q, DS0000);

   specify
     // delay parameters
     specparam
       tpllh$CLK$Q = 0.119553:0.119553:0.119553,
       tplhl$CLK$Q = 0.207353:0.207353:0.207353,
       tsetup_posedge$D$CLK = 0.25625:0.25625:0.25625,
       tsetup_negedge$D$CLK = 0.25625:0.25625:0.25625,
       thold_posedge$D$CLK = -0.0687499:-0.0687499:-0.0687499,
       thold_negedge$D$CLK = -0.0687499:-0.0687499:-0.0687499,
       tminpwh$CLK = 0.0643839:0.135868:0.207353,
       tminpwl$CLK = 0.0677888:0.12399:0.180191;

     // path delays
     if (CLK == 1'b1)
       (CLK *> Q) = (tpllh$CLK$Q, tplhl$CLK$Q);
     $setuphold(posedge CLK, negedge D, tsetup_negedge$D$CLK, thold_negedge$D$CLK, NOTIFIER);
     $setuphold(posedge CLK, posedge D, tsetup_posedge$D$CLK, thold_posedge$D$CLK, NOTIFIER);
     $width(posedge CLK, tminpwh$CLK, 0, NOTIFIER);
     $width(negedge CLK, tminpwl$CLK, 0, NOTIFIER);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module FAX1 (A, B, C, YC, YS);
input  A ;
input  B ;
input  C ;
output YC ;
output YS ;

   and (I0_out, A, B);
   and (I1_out, B, C);
   or  (I2_out, I0_out, I1_out);
   and (I3_out, C, A);
   or  (YC, I2_out, I3_out);
   xor (I5_out, A, B);
   xor (YS, I5_out, C);

   specify
     // delay parameters
     specparam
       tpllh$A$YS = 0.248162:0.257662:0.267162,
       tplhl$A$YS = 0.231317:0.232179:0.233041,
       tpllh$A$YC = 0.142399:0.142424:0.142448,
       tphhl$A$YC = 0.170702:0.172365:0.174028,
       tpllh$B$YS = 0.25527:0.265133:0.274996,
       tplhl$B$YS = 0.23523:0.239802:0.244374,
       tpllh$B$YC = 0.133566:0.14699:0.160415,
       tphhl$B$YC = 0.173225:0.175572:0.17792,
       tpllh$C$YS = 0.248643:0.254691:0.260738,
       tplhl$C$YS = 0.23558:0.235614:0.235648,
       tpllh$C$YC = 0.13532:0.138991:0.142662,
       tphhl$C$YC = 0.158684:0.161862:0.16504;

     // path delays
     (A *> YC) = (tpllh$A$YC, tphhl$A$YC);
     (A *> YS) = (tpllh$A$YS, tplhl$A$YS);
     (B *> YC) = (tpllh$B$YC, tphhl$B$YC);
     (B *> YS) = (tpllh$B$YS, tplhl$B$YS);
     (C *> YC) = (tpllh$C$YC, tphhl$C$YC);
     (C *> YS) = (tpllh$C$YS, tplhl$C$YS);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module HAX1 (A, B, YC);
input  A ;
input  B ;
output YC ;

   and (YC, A, B);

   specify
     // delay parameters
     specparam
       tpllh$A$YC = 0.103841:0.103841:0.103841,
       tphhl$A$YC = 0.142779:0.142779:0.142779,
       tpllh$B$YC = 0.102179:0.102179:0.102179,
       tphhl$B$YC = 0.12836:0.12836:0.12836;

     // path delays
     (A *> YC) = (tpllh$A$YC, tphhl$A$YC);
     (B *> YC) = (tpllh$B$YC, tphhl$B$YC);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module INVX1 (A, Y);
input  A ;
output Y ;

   not (Y, A);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0395681:0.0395681:0.0395681,
       tphlh$A$Y = 0.0480413:0.0480413:0.0480413;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module INVX2 (A, Y);
input  A ;
output Y ;

   not (Y, A);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0408301:0.0408301:0.0408301,
       tphlh$A$Y = 0.0483915:0.0483915:0.0483915;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module INVX4 (A, Y);
input  A ;
output Y ;

   not (Y, A);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0408301:0.0408301:0.0408301,
       tphlh$A$Y = 0.0483915:0.0483915:0.0483915;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module INVX8 (A, Y);
input  A ;
output Y ;

   not (Y, A);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0408301:0.0408301:0.0408301,
       tphlh$A$Y = 0.0483915:0.0483915:0.0483915;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module MUX2X1 (A, B, S, Y);
input  A ;
input  B ;
input  S ;
output Y ;

   udp_mux2 (I0_out, B, A, S);
   not (Y, I0_out);

   specify
     // delay parameters
     specparam
       tpllh$S$Y = 0.131432:0.131432:0.131432,
       tplhl$S$Y = 0.12645:0.12645:0.12645,
       tplhl$A$Y = 0.0607508:0.0607508:0.0607508,
       tphlh$A$Y = 0.0915759:0.0915759:0.0915759,
       tplhl$B$Y = 0.0670566:0.0670566:0.0670566,
       tphlh$B$Y = 0.0821321:0.0821321:0.0821321;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (S *> Y) = (tpllh$S$Y, tplhl$S$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module NAND2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   and (I0_out, A, B);
   not (Y, I0_out);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0376922:0.0376922:0.0376922,
       tphlh$A$Y = 0.0694331:0.0694331:0.0694331,
       tplhl$B$Y = 0.0393732:0.0393732:0.0393732,
       tphlh$B$Y = 0.0562541:0.0562541:0.0562541;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module NAND3X1 (A, B, C, Y);
input  A ;
input  B ;
input  C ;
output Y ;

   and (I0_out, A, B);
   and (I1_out, I0_out, C);
   not (Y, I1_out);

   specify
     // delay parameters
     specparam
       tplhl$B$Y = 0.0442348:0.0442348:0.0442348,
       tphlh$B$Y = 0.0861185:0.0861185:0.0861185,
       tplhl$A$Y = 0.047638:0.047638:0.047638,
       tphlh$A$Y = 0.100772:0.100772:0.100772,
       tplhl$C$Y = 0.0410599:0.0410599:0.0410599,
       tphlh$C$Y = 0.0647044:0.0647044:0.0647044;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module NOR2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   or  (I0_out, A, B);
   not (Y, I0_out);

   specify
     // delay parameters
     specparam
       tplhl$B$Y = 0.0541342:0.0541342:0.0541342,
       tphlh$B$Y = 0.0553978:0.0553978:0.0553978,
       tplhl$A$Y = 0.0678382:0.0678382:0.0678382,
       tphlh$A$Y = 0.0612638:0.0612638:0.0612638;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module NOR3X1 (A, B, C, Y);
input  A ;
input  B ;
input  C ;
output Y ;

   or  (I0_out, A, B);
   or  (I1_out, I0_out, C);
   not (Y, I1_out);

   specify
     // delay parameters
     specparam
       tplhl$B$Y = 0.092581:0.092581:0.092581,
       tphlh$B$Y = 0.0872453:0.0872453:0.0872453,
       tplhl$C$Y = 0.0672677:0.0672677:0.0672677,
       tphlh$C$Y = 0.0600795:0.0600795:0.0600795,
       tplhl$A$Y = 0.105275:0.105275:0.105275,
       tphlh$A$Y = 0.0900549:0.0900549:0.0900549;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module OAI21X1 (A, B, C, Y);
input  A ;
input  B ;
input  C ;
output Y ;

   or  (I0_out, A, B);
   and (I1_out, I0_out, C);
   not (Y, I1_out);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0598509:0.0598509:0.0598509,
       tphlh$A$Y = 0.0848161:0.0848161:0.0848161,
       tplhl$B$Y = 0.0496495:0.0496495:0.0496495,
       tphlh$B$Y = 0.0792513:0.0792513:0.0792513,
       tplhl$C$Y = 0.0361497:0.0461676:0.0561856,
       tphlh$C$Y = 0.0588879:0.0610346:0.0631813;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module OAI22X1 (A, B, C, D, Y);
input  A ;
input  B ;
input  C ;
input  D ;
output Y ;

   or  (I0_out, A, B);
   or  (I1_out, C, D);
   and (I2_out, I0_out, I1_out);
   not (Y, I2_out);

   specify
     // delay parameters
     specparam
       tplhl$D$Y = 0.0464815:0.0573095:0.0681375,
       tphlh$D$Y = 0.0691457:0.0712034:0.0732611,
       tplhl$C$Y = 0.0538466:0.0661742:0.0785018,
       tphlh$C$Y = 0.0759071:0.0772501:0.0785931,
       tplhl$A$Y = 0.0588601:0.0705872:0.0823143,
       tphlh$A$Y = 0.0928587:0.0970189:0.101179,
       tplhl$B$Y = 0.0515688:0.0621707:0.0727725,
       tphlh$B$Y = 0.0874558:0.0917204:0.0959849;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (B *> Y) = (tphlh$B$Y, tplhl$B$Y);
     (C *> Y) = (tphlh$C$Y, tplhl$C$Y);
     (D *> Y) = (tphlh$D$Y, tplhl$D$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module OR2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   or  (Y, A, B);

   specify
     // delay parameters
     specparam
       tpllh$B$Y = 0.116606:0.116606:0.116606,
       tphhl$B$Y = 0.108477:0.108477:0.108477,
       tpllh$A$Y = 0.0999577:0.0999577:0.0999577,
       tphhl$A$Y = 0.10024:0.10024:0.10024;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tphhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module OR2X2 (A, B, Y);
input  A ;
input  B ;
output Y ;

   or  (Y, A, B);

   specify
     // delay parameters
     specparam
       tpllh$B$Y = 0.1395:0.1395:0.1395,
       tphhl$B$Y = 0.130336:0.130336:0.130336,
       tpllh$A$Y = 0.121762:0.121762:0.121762,
       tphhl$A$Y = 0.125138:0.125138:0.125138;

     // path delays
     (A *> Y) = (tpllh$A$Y, tphhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tphhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module TBUFX1 (A, EN, Y);
input  A ;
input  EN ;
output Y ;

   not (I0_out, A);
   bufif1 (Y, I0_out, EN);

   specify
     // delay parameters
     specparam
       tpzh$EN$Y = 0.0841878:0.0841878:0.0841878,
       tpzl$EN$Y = 0.0245445:0.0245445:0.0245445,
       tplz$EN$Y = 0.05226:0.05226:0.05226,
       tphz$EN$Y = 0.072035:0.072035:0.072035,
       tplhl$A$Y = 0.0532632:0.0532632:0.0532632,
       tphlh$A$Y = 0.0821096:0.0821096:0.0821096;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (EN *> Y) = (0, 0, tplz$EN$Y, tpzh$EN$Y, tphz$EN$Y, tpzl$EN$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module TBUFX2 (A, EN, Y);
input  A ;
input  EN ;
output Y ;

   not (I0_out, A);
   bufif1 (Y, I0_out, EN);

   specify
     // delay parameters
     specparam
       tplhl$A$Y = 0.0531388:0.0531388:0.0531388,
       tphlh$A$Y = 0.0822629:0.0822629:0.0822629,
       tpzh$EN$Y = 0.0855464:0.0855464:0.0855464,
       tpzl$EN$Y = 0.0247174:0.0247174:0.0247174,
       tplz$EN$Y = 0.05226:0.05226:0.05226,
       tphz$EN$Y = 0.0727541:0.0727541:0.0727541;

     // path delays
     (A *> Y) = (tphlh$A$Y, tplhl$A$Y);
     (EN *> Y) = (0, 0, tplz$EN$Y, tpzh$EN$Y, tphz$EN$Y, tpzl$EN$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module XNOR2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   xor (I0_out, A, B);
   not (Y, I0_out);

   specify
     // delay parameters
     specparam
       tpllh$A$Y = 0.108256:0.108256:0.108256,
       tplhl$A$Y = 0.0981478:0.0981478:0.0981478,
       tpllh$B$Y = 0.127784:0.127784:0.127784,
       tplhl$B$Y = 0.10959:0.10959:0.10959;

     // path delays
     (A *> Y) = (tpllh$A$Y, tplhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tplhl$B$Y);

   endspecify

endmodule
`endcelldefine

`timescale 1ns/10ps
`celldefine
module XOR2X1 (A, B, Y);
input  A ;
input  B ;
output Y ;

   xor (Y, A, B);

   specify
     // delay parameters
     specparam
       tpllh$B$Y = 0.122197:0.122197:0.122197,
       tplhl$B$Y = 0.112382:0.112382:0.112382,
       tpllh$A$Y = 0.108542:0.108542:0.108542,
       tplhl$A$Y = 0.0979899:0.0979899:0.0979899;

     // path delays
     (A *> Y) = (tpllh$A$Y, tplhl$A$Y);
     (B *> Y) = (tpllh$B$Y, tplhl$B$Y);

   endspecify

endmodule
`endcelldefine

primitive udp_dff (out, in, clk, clr, set, NOTIFIER);
   output out;
   input  in, clk, clr, set, NOTIFIER;
   reg    out;

   table

// in  clk  clr   set  NOT  : Qt : Qt+1
//
   0  r   ?   0   ?   : ?  :  0  ; // clock in 0
   1  r   0   ?   ?   : ?  :  1  ; // clock in 1
   1  *   0   ?   ?   : 1  :  1  ; // reduce pessimism
   0  *   ?   0   ?   : 0  :  0  ; // reduce pessimism
   ?  f   ?   ?   ?   : ?  :  -  ; // no changes on negedge clk
   *  b   ?   ?   ?   : ?  :  -  ; // no changes when in switches
   ?  ?   ?   1   ?   : ?  :  1  ; // set output
   ?  b   0   *   ?   : 1  :  1  ; // cover all transistions on set
   1  x   0   *   ?   : 1  :  1  ; // cover all transistions on set
   ?  ?   1   0   ?   : ?  :  0  ; // reset output
   ?  b   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   0  x   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   ?  ?   ?   ?   *   : ?  :  x  ; // any notifier changed

   endtable
endprimitive // udp_dff

primitive udp_tlat (out, in, enable, clr, set, NOTIFIER);

   output out;
   input  in, enable, clr, set, NOTIFIER;
   reg    out;

   table

// in  enable  clr   set  NOT  : Qt : Qt+1
//
   1  1   0   ?   ?   : ?  :  1  ; //
   0  1   ?   0   ?   : ?  :  0  ; //
   1  *   0   ?   ?   : 1  :  1  ; // reduce pessimism
   0  *   ?   0   ?   : 0  :  0  ; // reduce pessimism
   *  0   ?   ?   ?   : ?  :  -  ; // no changes when in switches
   ?  ?   ?   1   ?   : ?  :  1  ; // set output
   ?  0   0   *   ?   : 1  :  1  ; // cover all transistions on set
   1  ?   0   *   ?   : 1  :  1  ; // cover all transistions on set
   ?  ?   1   0   ?   : ?  :  0  ; // reset output
   ?  0   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   0  ?   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   ?  ?   ?   ?   *   : ?  :  x  ; // any notifier changed

   endtable
endprimitive // udp_tlat

primitive udp_rslat (out, clr, set, NOTIFIER);

   output out;
   input  clr, set, NOTIFIER;
   reg    out;

   table

// clr   set  NOT  : Qt : Qt+1
//
   ?   1   ?   : ?  :  1  ; // set output
   0   *   ?   : 1  :  1  ; // cover all transistions on set
   1   0   ?   : ?  :  0  ; // reset output
   *   0   ?   : 0  :  0  ; // cover all transistions on clr
   ?   ?   *   : ?  :  x  ; // any notifier changed

   endtable
endprimitive // udp_tlat

primitive udp_mux2 (out, in0, in1, sel);
   output out;
   input  in0, in1, sel;

   table

// sel in0 in1 :  out
//
    1  ?  0 :  1 ;
    0  ?  0 :  0 ;
    ?  1  1 :  1 ;
    ?  0  1 :  0 ;
    0  0  x :  0 ;
    1  1  x :  1 ;

   endtable
endprimitive // udp_mux2

